<?php
/**
 * @file
 * Provides admin configuration for the SharpSpring Webforms module.
 */

/**
 * Defines the SharpSpring Webform configuration form.
 */
function sharpspring_webforms_config_form($form, &$form_state) {
  $form['sharpspring_webforms'] = array(
    '#title' => t('Webform Lead Generation'),
    '#description' => '<p>' . t("Add unique tracking IDs to each webform on the site. For each webform you want to track, enter the form's endpoint ID as it appears in the unique tracking code. It should be formatted like @endpoint.", array('@endpoint' => 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx (8-4-4-4-12)')) . '</p>',
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#tree' => TRUE,
  );

  // Get list of all webforms.
  $wf_query = db_select('webform', 'w')
    ->fields('w')
    ->orderBy('nid')
    ->addTag('node_access')
    ->execute()
    ->fetchAll();

  // Get list of all SharpSpring form endpoints.
  $webform_codes = _sharpspring_webforms_return_endpoint_values();

  foreach ($wf_query as $row) {
    if (!empty($row->nid)) {
      $webform = node_load($row->nid);

      $unpublished = (isset($webform->status)) ? !$webform->status : TRUE;

      $enabled = (!empty($webform_codes[$row->nid]->status)) ? $webform_codes[$row->nid]->status : 0;
      $endpoint = (!empty($webform_codes[$row->nid]->endpoint)) ? $webform_codes[$row->nid]->endpoint : '';
      $base_uri = (!empty($webform_codes[$row->nid]->base_uri)) ? $webform_codes[$row->nid]->base_uri : '';
      $title = (!empty($webform->title)) ? $webform->title : '';

      $form['sharpspring_webforms'][$row->nid] = array(
        '#type' => 'fieldset',
        '#collapsible' => FALSE,
        '#collapsed' => FALSE,
        '#states' => array(
          'visible' => array(
            ':input[name="' . $row->nid . '"]' => array('checked' => TRUE),
          ),
        ),
      );

      $form['sharpspring_webforms'][$row->nid]['header'] = array(
        '#markup' => '<h4 style="margin-top: -10px;">"' . check_plain($title) . '" Form</h4>',
      );

      $form['sharpspring_webforms'][$row->nid]['enable'] = array(
        '#title' => t('Enabled'),
        '#default_value' => $enabled,
        // Disable checkbox if form is unpublished.
        '#disabled' => $unpublished,
        '#type' => 'checkbox',
        '#size' => 50,
        '#maxlength' => 40,
      );

      $form['sharpspring_webforms'][$row->nid]['base_uri'] = array(
        '#title' => 'Base URI',
        '#description' => t("The form's baseURI will appear in the tracking code as:") . " <pre>__ss_noform.push(['baseURI', '<strong>https://app-XXXXXX.sharpspring.com/webforms/receivePostback/XXXXXXXX/</strong>']);</pre>",
        '#default_value' => $base_uri,
        '#type' => 'textfield',
        '#size' => 50,
        '#maxlength' => 255,
      );

      $form['sharpspring_webforms'][$row->nid]['endpoint'] = array(
        '#title' => 'Endpoint',
        '#description' => t("The form's endpoint will appear in the tracking code as:") . " <pre>__ss_noform.push(['endpoint', '<strong>xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx</strong>']);</pre>",
        '#default_value' => $endpoint,
        '#type' => 'textfield',
        '#size' => 70,
        '#maxlength' => 40,
      );
    }

  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );

  return $form;
}

/**
 * SharpSpring Webform admin form validation.
 */
function sharpspring_webforms_config_form_validate(&$form, &$form_state) {
  $vals = (!empty($form_state['values']['sharpspring_webforms'])) ? $form_state['values']['sharpspring_webforms'] : array();

  foreach ($vals as $wid => $values) {
    $status = (isset($values['enable'])) ? $values['enable'] : 0;
    $base_uri = (!empty($values['base_uri'])) ? $values['base_uri'] : '';
    $endpoint = (!empty($values['endpoint'])) ? $values['endpoint'] : '';

    // If the form tracking isn't active, it doesn't matter if these are wrong.
    if ($status == 1) {
      // Check whether the base URI and endpoint will actually work.
      if (!_sharpspring_validate_endpoint($endpoint)) {
        form_set_error('sharpspring_webforms][' . $wid . '][endpoint', t('A valid SharpSpring Endpoint is formatted like @endpoint. Please check for any whitespace in your entry.', array('@endpoint' => 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx')));
        continue;
      }
      if (!_sharpspring_validate_uri($base_uri)) {
        form_set_error('sharpspring_webforms][' . $wid . '][base_uri', t('A valid SharpSpring Base URI is formatted like @baseuri.', array('@baseuri' => 'https://app-XXXXXX.sharpspring.com/webforms/receivePostback/XXXXXXXX')));
        continue;
      }
    }
  }
}

/**
 * SharpSpring Webform admin form submit.
 */
function sharpspring_webforms_config_form_submit(&$form, &$form_state) {
  $vals = (!empty($form_state['values']['sharpspring_webforms'])) ? $form_state['values']['sharpspring_webforms'] : array();

  foreach ($vals as $wid => $values) {
    $status = (isset($values['enable'])) ? $values['enable'] : 0;
    $base_uri = (!empty($values['base_uri'])) ? $values['base_uri'] : '';
    $endpoint = (!empty($values['endpoint'])) ? $values['endpoint'] : '';

    // Check for existing webform settings.
    $result_check = db_select('sharpspring_webforms', 'nid')
      ->fields('nid')
      ->condition('nid', $wid, '=')
      ->execute();

    $existing = FALSE;
    foreach ($result_check as $result) {
      if (!empty($result)) {
        $existing = TRUE;
      }
    }

    // Now save new info.
    $table_name = 'sharpspring_webforms';
    $data = array(
      'nid' => $wid,
      'base_uri' => $base_uri,
      'endpoint' => $endpoint,
      'status' => $status,
    );

    if ($existing) {
      drupal_write_record($table_name, $data, 'nid');
    }
    else {
      drupal_write_record($table_name, $data);
    }

  }
}

/**
 * Shaprspring webform configuration form, placed on webform edit form
 *
 * @see hook_form_alter in sharpspring_webforms.module
 *
 * @param $form
 */
function sharpspring_webforms_webform_edit_config_form(&$form) {
  $webform_id = (!empty($form['nid']['#value'])) ? $form['nid']['#value'] : 0;

  // Grab results from the sharpspring_webforms table for the webform id.
  $endpoint_data = sharpspring_webforms_return_endpoint_data_for_webform_id($webform_id);

  // Presumably there should only be one value returned for the the webform_id from the table.
  $endpoint_data = array_shift($endpoint_data);
  $enabled = (!empty($endpoint_data->status)) ? $endpoint_data->status : 0;
  $endpoint = (!empty($endpoint_data->endpoint)) ? $endpoint_data->endpoint : '';
  $base_uri = (!empty($endpoint_data->base_uri)) ? $endpoint_data->base_uri : '';

  $form['sharpspring_webforms'] = array(
    '#type' =>'fieldset',
    '#title' => t('Sharpspring Webforms'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#group' => 'additional_settings',
    '#access' => user_access('administer sharpspring'),
    '#tree' => TRUE,
    '#weight' => 50,
    '#element_validate' => array('sharpspring_webforms_edit_config_form_validate'),
  );

  $form['sharpspring_webforms']['wid'] = array(
    '#type' => 'hidden',
    '#value' => $webform_id,
  );

  $form['sharpspring_webforms']['enable'] = array(
    '#title' => t('Enabled'),
    '#default_value' => $enabled,
//      // Disable checkbox if form is unpublished.
//      '#disabled' => $unpublished,
    '#type' => 'checkbox',
    '#size' => 50,
    '#maxlength' => 40,
  );

  $form['sharpspring_webforms']['base_uri'] = array(
    '#title' => 'Base URI',
    '#description' => t("The form's baseURI will appear in the tracking code as:") . " <pre>__ss_noform.push(['baseURI', '<strong>https://app-XXXXXX.sharpspring.com/webforms/receivePostback/XXXXXXXX/</strong>']);</pre>",
    '#default_value' => $base_uri,
    '#type' => 'textfield',
    '#size' => 50,
    '#maxlength' => 255,
  );

  $form['sharpspring_webforms']['endpoint'] = array(
    '#title' => 'Endpoint',
    '#description' => t("The form's endpoint will appear in the tracking code as:") . " <pre>__ss_noform.push(['endpoint', '<strong>xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx</strong>']);</pre>",
    '#default_value' => $endpoint,
    '#type' => 'textfield',
    '#size' => 70,
    '#maxlength' => 40,
  );

  $form['#submit'][] = 'sharpspring_webforms_edit_config_form_submit';
}

/**
 * SharpSpring Webform edit form validation.
 */
function sharpspring_webforms_edit_config_form_validate(&$form, &$form_state) {
  $vals = (!empty($form_state['values']['sharpspring_webforms'])) ? $form_state['values']['sharpspring_webforms'] : array();

  $status = (isset($vals['enable'])) ? $vals['enable'] : 0;
  $base_uri = (!empty($vals['base_uri'])) ? $vals['base_uri'] : '';
  $endpoint = (!empty($vals['endpoint'])) ? $vals['endpoint'] : '';

  // If the form tracking isn't active, it doesn't matter if these are wrong.
  if ($status == 1) {
    // Check whether the base URI and endpoint will actually work.
    if (!_sharpspring_validate_endpoint($endpoint)) {
      form_set_error('sharpspring_webforms][endpoint', t('A valid SharpSpring Endpoint is formatted like @endpoint. Please check for any whitespace in your entry.', array('@endpoint' => 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx')));
    }
    if (!_sharpspring_validate_uri($base_uri)) {
      form_set_error('sharpspring_webforms][base_uri', t('A valid SharpSpring Base URI is formatted like @baseuri.', array('@baseuri' => 'https://app-XXXXXX.sharpspring.com/webforms/receivePostback/XXXXXXXX')));
    }
  }

}

/**
 * SharpSpring Webform admin form submit.
 */
function sharpspring_webforms_edit_config_form_submit(&$form, &$form_state) {
  $vals = (!empty($form_state['values']['sharpspring_webforms'])) ? $form_state['values']['sharpspring_webforms'] : array();

  $status = (isset($vals['enable'])) ? $vals['enable'] : 0;
  $base_uri = (!empty($vals['base_uri'])) ? $vals['base_uri'] : '';
  $endpoint = (!empty($vals['endpoint'])) ? $vals['endpoint'] : '';
  $wid = (!empty($vals['wid'])) ? $vals['wid'] : 0;

  // Check for existing webform settings.
  $result_check = db_select('sharpspring_webforms', 'nid')
    ->fields('nid')
    ->condition('nid', $wid, '=')
    ->execute();

  $existing = FALSE;
  foreach ($result_check as $result) {
    if (!empty($result)) {
      $existing = TRUE;
    }
  }

  // Now save new info.
  $table_name = 'sharpspring_webforms';
  $data = array(
    'nid' => $wid,
    'base_uri' => $base_uri,
    'endpoint' => $endpoint,
    'status' => $status,
  );

  if ($existing) {
    drupal_write_record($table_name, $data, 'nid');
  }
  else {
    drupal_write_record($table_name, $data);
  }

}
